@@ -61,7 +61,10 @@ impl Melter {
         let mut in_object = 1;
         let mut token_idx = 0;
         let mut known_number = false;
+        let mut known_unquote = false;
         let mut reencode_float_token = false;
+        let mut alive_data_index = 0;
+        let mut unquote_list_index = 0;
         let tokens = tape.tokens();
 
         while let Some(token) = tokens.get(token_idx) {
@@ -102,6 +105,15 @@ impl Melter {
                     if !matches!(tokens.get(*x), Some(BinaryToken::HiddenObject(_))) {
                         writer.push(b'}');
                     }
+
+                    if *x == alive_data_index {
+                        alive_data_index = 0;
+                    }
+
+                    if *x == unquote_list_index {
+                        unquote_list_index = 0;
+                    }
+
                     let obj = in_objects.pop();
 
                     // The binary parser should already ensure that this will be something, but this is
@@ -135,7 +147,7 @@ impl Melter {
                     };
 
                     // quoted fields occuring as keys should remain unquoted
-                    if in_object == 1 {
+                    if in_object == 1 || known_unquote {
                         writer.extend_from_slice(&data[..end_idx]);
                     } else {
                         writer.push(b'"');
@@ -152,7 +164,12 @@ impl Melter {
                     write!(writer, "{}", x).map_err(Ck3ErrorKind::IoErr)?
                 }
                 BinaryToken::F64(x) => {
-                    write!(writer, "{}", reencode_float(*x)).map_err(Ck3ErrorKind::IoErr)?;
+                    let x = reencode_float(*x);
+                    if x.fract() > 1e-7 {
+                        write!(writer, "{:.5}", x).map_err(Ck3ErrorKind::IoErr)?;
+                    } else {
+                        write!(writer, "{}", x).map_err(Ck3ErrorKind::IoErr)?;
+                    }
                     reencode_float_token = false;
                 }
                 BinaryToken::Token(x) => match TokenLookup.resolve(*x) {
@@ -170,15 +187,41 @@ impl Melter {
                         continue;
                     }
                     Some(id) => {
+                        if in_object == 1 && id == "alive_data" {
+                            alive_data_index = token_idx + 1;
+                        }
+
+                        if in_object == 1 && matches!(id, "settings" | "setting" | "perks")
+                            || (id == "perk" && alive_data_index != 0)
+                        {
+                            unquote_list_index = token_idx + 1;
+                        }
+
                         known_number = in_object == 1 && id == "seed";
+                        known_unquote = unquote_list_index != 0
+                            || matches!(
+                                id,
+                                "save_game_version"
+                                    | "portraits_version"
+                                    | "meta_date"
+                                    | "color1"
+                                    | "color2"
+                                    | "color3"
+                                    | "color4"
+                                    | "color5"
+                            );
+
                         reencode_float_token = in_object == 1
                             && matches!(
                                 id,
-                                "gold"
-                                    | "vassal_power_value"
+                                "vassal_power_value"
                                     | "budget_war_chest"
                                     | "budget_short_term"
+                                    | "budget_long_term"
+                                    | "budget_reserved"
                             );
+                        reencode_float_token |=
+                            in_object == 1 && alive_data_index != 0 && id == "gold";
                         writer.extend_from_slice(&id.as_bytes())
                     }
                     None => {
@@ -245,7 +288,14 @@ impl Melter {
             let split_ind = data.iter().position(|&x| x == b'\n').unwrap_or(0);
             let at = std::cmp::max(split_ind, 0);
             let (header, rest) = data.split_at(at + 1);
-            result.extend_from_slice(header);
+            let mut mutted = header.to_vec();
+            // Set the type to 0, type list:
+            // 0: Uncompressed + Plaintext
+            // 1: Uncompressed + Binary
+            // 2: Compressed + Plaintext
+            // 3: Compressed + Binary
+            mutted["SAV010".len()] = b'0';
+            result.extend_from_slice(&mutted);
             rest
         } else {
             data
